Stan Math Library: stan/math/prim/mat/fun/fill.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
fill.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int R, int C, typename S >
void | stan::math::fill (Eigen::Matrix< T, R, C > &x, const S &y)
| Fill the specified container with the specified value. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.